@@ -1,10 +1,10 @@
 package Benchmark::Perl::Formance;
-# git description: v0.36-2-g46f4583
+# git description: v0.37-14-g96ffee5
 
 BEGIN {
   $Benchmark::Perl::Formance::AUTHORITY = 'cpan:SCHWIGON';
 }
-$Benchmark::Perl::Formance::VERSION = '0.37';
+$Benchmark::Perl::Formance::VERSION = '0.38';
 use 5.008;
 
 use warnings;
@@ -26,11 +26,12 @@ use Sys::Hostname;
 use Sys::Info;
 use FindBin qw($Bin);
 
-# comma separated list of default plugins
+# comma separated list of default plugins - basically the non-troublemakers
 my $DEFAULT_PLUGINS = join ",", qw(DPath
                                    Fib
                                    FibOO
                                    Mem
+                                   MatrixReal
                                    Prime
                                    Rx
                                    Shootout::fasta
@@ -47,6 +48,8 @@ my $ALL_PLUGINS = join ",", qw(DPath
                                FibMoose
                                FibMouse
                                FibOO
+                               FibOOSig
+                               MatrixReal
                                Mem
                                P6STD
                                PerlCritic
