@@ -6,7 +6,7 @@ BEGIN {
 use strict;
 use warnings;
 
-our $VERSION = "0.002";
+our $VERSION = "0.003";
 
 #############################################################
 #                                                           #
@@ -27,6 +27,9 @@ use Benchmark ':hireswallclock';
 sub main {
         my ($options) = @_;
 
+        require Mail::SpamAssassin;
+        my $sa_version = $Mail::SpamAssassin::VERSION;
+
         my $srcdir; eval { $srcdir = dist_dir('Benchmark-Perl-Formance-Cargo')."/SpamAssassin" };
         if ($@) {
                 return { salearn => { failed => "no Benchmark-Perl-Formance-Cargo" } }
@@ -77,6 +80,7 @@ sub main {
                 $results{salearn}{$pass->{metric}} = {
                                                       Benchmark    => [@$t],
                                                       salearn_path => $salearn,
+                                                      sa_version   => $sa_version,
                                                       count        => $count,
                                                      };
         }
